@@ -8,17 +8,21 @@ from .product import (
 
 class EmergencyReportingClient():
 
-    def __init__(self, client_id=None, client_secret=None, username=None, password=None):
+    def __init__(self, client_id=None, client_secret=None, username=None, password=None, er_uid=None, er_aid=None):
         self.client_id = client_id
         self.client_secret = client_secret
         self.username = username
         self.password = password
+        self.er_aid = er_aid
+        self.er_uid = er_uid
         self.AgencyIncidentsProduct = AgencyIncidentsProduct(
             BaseSubscription(
                 client_id=client_id,
                 client_secret=client_secret,
                 username=username,
-                password=password
+                password=password,
+                er_aid=er_aid,
+                er_uid=er_uid
                 )
             )
         self.AgencyAdministrationProduct = AgencyAdministrationProduct(
@@ -26,7 +30,9 @@ class EmergencyReportingClient():
                 client_id=client_id,
                 client_secret=client_secret,
                 username=username,
-                password=password
+                password=password,
+                er_aid=er_aid,
+                er_uid=er_uid
                 )
         )
         self.AgencyClassesProduct = AgencyClassesProduct(
@@ -34,7 +40,9 @@ class EmergencyReportingClient():
                 client_id=client_id,
                 client_secret=client_secret,
                 username=username,
-                password=password
+                password=password,
+                er_aid=er_aid,
+                er_uid=er_uid
                 )
         )
 
