@@ -5,7 +5,7 @@ class BaseSubscription():
 
     def __init__(
             self, client_id, client_secret,
-            username, password,
+            username, password, er_aid, er_uid,
             primary_key=None, secondary_key=None):
-        self.Auth = Auth(client_id, client_secret, username, password)
+        self.Auth = Auth(client_id, client_secret, username, password, er_aid, er_uid)
         self.Auth.primary_key = primary_key
